function bandpassfilter
%Matlab FIR filter creator written by Ellen Yi Chen 2009

close all

%Create a signal
dt = 0.1;
t = 0:dt:100;
sig = sin(0.5*pi*t)+cos(0.6*pi*t);        %frequency = 0.25 Hz and 0.3 Hz

%Create the heavy noise ontop of the signal
noise = 2*(rand(size(sig))-0.5);
noisysig = sig + noise;

%Create the bandpass filter
Fs = 1/dt;                        %sampling frequency
F = [0.15 0.22 0.32 0.4];        %centered on 0.25Hz and 0.3Hz.  The middle two numbers are cutoff frequencies (one below 0.25 and one above 0.25)
A = [0 1 0];                      %this line creates a band pass filter. [1 0] will create a low pass filter, etc...
DEV = [0.1 0.005 0.1];             %this determines the deviation from A that you would like to allow
[N,Wn,BTA,FILTYPE] = kaiserord(F,A,DEV,Fs);   %for more details on designing filters, use 'help kaiserord'
N = N + rem(N,2);
format long
B = fir1(N, Wn, FILTYPE, kaiser(N+1), 'noscale' )    %This line gives the B's needed for the FIR filter constants
fsignal = filter(B,1, noisysig);

%plot the original signal, noisy signal and filtered signal
figure
plot(t, sig, t, noisysig, t, fsignal)
xlabel('Time (s)');ylabel('Signal'); title('Filtered Signal')
legend('Signal', 'Noisy Signal', 'Filtered Signal')

%plot the first 200 samples
figure
plot(t(1:200), sig(1:200), t(1:200), noisysig(1:200), t(1:200), fsignal(1:200))
xlabel('Time (s)');ylabel('Signal'); title('Filtered Signal')
legend('Signal', 'Noisy Signal', 'Filtered Signal')

%frequency plot
figure
den = [1 (zeros(1,size(B,2)-1))];
freqz(B',den'); 

%pole zero plot
[myzeros,mypoles]=tf2zp(B,den);
figure
zplane(myzeros,mypoles)

%frequency plot
figure
sig1 = abs(fft(sig));
sig2 = abs(fft(noisysig));
sig3 = abs(fft(fsignal));
size(sig1,2)
f = ((0:1:(size(sig1,2)-1)))/100;
plot(f,sig1,f,sig2,f,sig3)
xlim([0 5])
xlabel('Frequency (Hz)');ylabel('Signal'); title('Frequency Plot')
legend('Signal', 'Noisy Signal', 'Filtered Signal')