
function motorStruct = motorConstructor( rand )
% motorConstructor( rand )  
%
%  Creates a new motor structure. If the given parameter rand 
%  is supplied then the motor parameters are normally distributed
%  around the default values.
%
%  See also motorSetVoltage, motorStepResponse, and motorPID

  % Damping ratio of the mechanical system
  motorStruct.b = 0.1;

  % Moment of inertia of the rotor
  motorStruct.J = 0.01;

  % Elctromotive force constant (Nm/Amp)
  motorStruct.K = 0.01;

  % Electric resistance (ohm)
  motorStruct.R = 1;

  % Electric inductance (H)
  motorStruct.L = 0.5;

  % Motor position (deg)
  motorStruct.theta = 0;
  
  % Motor velocity (deg/sec)
  motorStruct.vel = 0;

  % Motor current (Amp)
  motorStruct.I = 0;

  if ( nargin == 1 )
    motorStruct.K = 0.01 + 0.0005*randn;
    motorStruct.b = 0.1  + 0.005*randn;
    motorStruct.J = 0.01 + 0.0005*randn;
    motorStruct.R = 1    + 0.05*randn;
    motorStruct.L = 0.5  + 0.005*randn;
  end
