
function [ timespan, vel ] = motorPID( motorStruct, timestep, maxtime, Kp, Ki, Kd )
% [ timespan, vel ] = motorPID( motorStruct, timestep, maxtime, Kp, Ki, Kd )
%
%  Feeds a unit step function into the motor given by the 
%  motorStruct - where the motor is controlled by a PID loop.
%  The Kp, Ki, and Kd constants refer to the proportional,
%  integral, and derivative constants respecively.
%  
%  See also motorConstructor, motorSetVoltage, and motorStepResponse

  timespan = [ 0 : timestep : maxtime ];

  prevError = 0;
  errorSum = 0;
  setVel = 1;
  k = 1;
  for i = timespan

    motorStruct = motorSetVoltage( motorStruct, timestep, setVel );
    vel(k) = motorStruct.vel;
    k = k + 1;

    error     = 1 - motorStruct.vel;
    errorSum  = errorSum + error;
    errorInt  = errorSum*i;
    errorDiff = (prevError - error)/timestep;
    
    setVel = 1 + Kp*error + Ki*errorInt - Kd*errorDiff;

    prevError = error;

  end  
