
function motorStruct = motorSetVeoltage( motorStruct, timestep, V );
% motorSetVoltage( motorStruct, timestep, voltage );
%  Sets the motor supplied in the motorStruct to the given 
%  voltage over the given timestep. The motor model is composed
%  of three differential equations derived from the description 
%  given at the http://www.engin.umich.edu/group/ctm/examples/motor/motor.html
%
%  See also motorConstructor, motorStepResponse, and motorPID

  b = motorStruct.b; % Damping ratio of the mechanical system
  J = motorStruct.J; % Moment of inertia of the rotor
  K = motorStruct.K; % Elctromotive force constant (Nm/Amp)
  L = motorStruct.L; % Electric inductance (H)     
  R = motorStruct.R; % Electric resistance (ohm)

  theta = motorStruct.theta; % Position of motor shaft
  vel   = motorStruct.vel;   % Velocity of motor shaft
  I     = motorStruct.I;     % Motor current

  % These three differential equations provide the motor 
  % model. They were derived from the description given at the 
  % http://www.engin.umich.edu/group/ctm/examples/motor/motor.html

  motorStruct.theta = theta + (vel)*timestep;
  motorStruct.vel   = vel + ((-b/J)*vel + (K/J)*I)*timestep;
  motorStruct.I     = I + ((-R/L)*I + (V/L) - (K/L)*vel)*timestep;
  
